[Zope-Checkins] CVS: Zope/lib/python/Products/Transience/tests - fauxtime.py:1.3

Chris McDonough chrism@zope.com
Thu, 30 Jan 2003 20:14:25 -0500


Update of /cvs-repository/Zope/lib/python/Products/Transience/tests
In directory cvs.zope.org:/tmp/cvs-serv6424

Modified Files:
	fauxtime.py 
Log Message:
Supercharge fauxtime to reduce the time taken for tests.


=== Zope/lib/python/Products/Transience/tests/fauxtime.py 1.2 => 1.3 ===
--- Zope/lib/python/Products/Transience/tests/fauxtime.py:1.2	Wed Aug 14 18:25:14 2002
+++ Zope/lib/python/Products/Transience/tests/fauxtime.py	Thu Jan 30 20:14:23 2003
@@ -3,9 +3,9 @@
 epoch = origtime.time()
 
 def time():
-    """ False timer -- returns time 10 x faster than normal time """
-    return (origtime.time() - epoch) * 10.0
+    """ False timer -- returns time 60 x faster than normal time """
+    return (origtime.time() - epoch) * 60.0
 
 def sleep(duration):
-    """ False sleep -- sleep for 1/10 the time specifed """
-    origtime.sleep(duration / 10.0)
+    """ False sleep -- sleep for 1/60 the time specifed """
+    origtime.sleep(duration / 60.0)